/*------------------------------------------------------------------------------
;
;   Easy Loader.
;
;   Compatible with The Cowboy Boot Loader for Enhanced PIC12/PIC16,
;                   The Wellington Boot Loader for PIC18 and
;                   The Oxford Boot Loader for dsPIC/PIC24.
;
;   Copyright (c) 2014 - 2017 Darron M Broad
;   Copyright (c) 2014 Gerhard Bertelsmann
;
;-------------------------------------------------------------------------------

;-------------------------------------------------------------------------------
;   This file is part of Easy Loader.
;
;   Easy Loader is free software: you can redistribute it and/or
;   modify it under the terms of the GNU General Public License as published
;   by the Free Software Foundation.
;
;   Easy Loader is distributed in the hope that it will be
;   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
;   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
;   GNU General Public License for more details.
;
;   You should have received a copy of the GNU General Public License along
;   with Easy Loader. If not, see http://www.gnu.org/licenses/
;-----------------------------------------------------------------------------*/

#ifndef _CMD_H
#define _CMD_H

/******************************************************************************
 * BOOT LOADER COMMANDS
 */

#define COMMAND_VERSION     (0x90)
#define COMMAND_HELLO       (0x91)
#define COMMAND_FLASH_ERASE (0x92)
#define COMMAND_FLASH_WRITE (0x93)
#define COMMAND_FLASH_READ  (0x94)
#define COMMAND_EE_ERASE    (0x95)
#define COMMAND_EE_WRITE    (0x96)
#define COMMAND_EE_READ     (0x97)
#define COMMAND_RUN         (0x98)

/*
 * [FLASH|EE] [READ|WRITE] command
 */
#define PROGRAM_SIZE (6)
typedef struct program_packet {
	uint8_t command;
	uint8_t addru, addrh, addrl;
	uint8_t datasize;
	uint8_t data[BUFLEN - PROGRAM_SIZE];	/* buffer + checksum */
} __attribute__((packed)) program_t;


/******************************************************************************
 * BOOT LOADER RESPONSES
 */

#define RESPONSE_OK     'O'
#define RESPONSE_ERRCMD 'E'
#define RESPONSE_ERRSUM 'S'

/*
 * HELLO response
 */
typedef struct hello_packet {
	uint8_t wordsize;
	uint8_t writesize;
	uint8_t erasesizeh, erasesizel;
	uint8_t startu, starth, startl;
	uint8_t eesize;
	uint8_t option;
	uint8_t response;
} __attribute__((packed)) hello_t;

#define SRCPACKED (1)

/*****************************************************************************/

int doCommand(int, int);
int helloCommand(void);
int runCommand(void);
int versionCommand(void);
void programChecksum(uint16_t);

#endif /* !_CMD_H */
