/*------------------------------------------------------------------------------
;
;   Easy Loader.
;
;   Compatible with The Cowboy Boot Loader for Enhanced PIC12/PIC16,
;                   The Wellington Boot Loader for PIC18 and
;                   The Oxford Boot Loader for dsPIC/PIC24.
;
;   Copyright (c) 2014 - 2017 Darron M Broad
;   Copyright (c) 2014 Gerhard Bertelsmann
;
;-------------------------------------------------------------------------------

;-------------------------------------------------------------------------------
;   This file is part of Easy Loader.
;
;   Easy Loader is free software: you can redistribute it and/or
;   modify it under the terms of the GNU General Public License as published
;   by the Free Software Foundation.
;
;   Easy Loader is distributed in the hope that it will be
;   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
;   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
;   GNU General Public License for more details.
;
;   You should have received a copy of the GNU General Public License along
;   with Easy Loader. If not, see http://www.gnu.org/licenses/
;-----------------------------------------------------------------------------*/

#ifndef _EASY_LOADER_H
#define _EASY_LOADER_H

/*
 * UNIX and Linux header files
 */
#include <stdio.h>
#include <stdlib.h>
#include <stdint.h>
#include <memory.h>
#include <fcntl.h>
#include <errno.h>
#include <unistd.h>
#include <termios.h>
#include <assert.h>
#include <ctype.h>
#include <limits.h>
#include <sysexits.h>
#include <sys/select.h>
#include <sys/types.h>
#include <sys/time.h>
#include <sys/ioctl.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <netinet/in.h>
#include <netinet/tcp.h>
#include <netdb.h>
#include <net/if.h>
#ifdef __linux
#include <linux/can.h>
#endif

/*
 * Easy loader buffer
 */
#define BUFLEN (8192)
#define BUFMAX (BUFLEN - 1)

/*
 * Easy loader session
 */
typedef struct {
	FILE *info;		/* Information stream output     */
	int fd;			/* I/O file descriptor           */
	int fdtyp;		/* I/O type 0=SERIAL, 1=CAN BUS  */
	int cid;		/* CAN BUS id                    */
	uint8_t version;	/* VERSION CODE                  */
	uint8_t arch;		/* 16=PIC18 24=dsPIC/PIC24       */
	uint8_t writesize;	/* WRITE SIZE in bytes or words  */
	uint16_t erasesize;	/* ERASE SIZE in bytes or words  */
	uint32_t startaddr;	/* 24-bit boot loader address    */
	uint16_t eesize;	/* EEPROM SIZE in bytes or words */
	uint8_t option;		/* OPTIONS                       */
	uint32_t delay;		/* Delay after open              */
	uint8_t buffer[BUFLEN];	/* I/O buffer                    */
	uint32_t wiener;	/* Hard Wiener reset (DTR + CAP) */
	uint32_t winkle;	/* Winklepicker mode 2 reset     */
	uint32_t rts;		/* De-assert RTS                 */
	uint32_t dtr;		/* De-assert DTR                 */
	uint32_t brk;		/* Send BREAK                    */
	uint32_t txdrain;	/* Tx drain for software UART    */
	uint32_t baudrate;	/* Serial rate                   */
	uint8_t autorun;	/* Run firmware                  */
	uint8_t simulate;	/* Simulate writing              */
	uint8_t verify;		/* Verify after write            */
} session_t;

/*
 * Easy loader includes
 */
#include "canbus.h"
#include "cmd.h"
#include "easy-loader.h"
#include "inhx32.h"
#include "io.h"
#include "pic.h"
#include "pic14.h"
#include "pic16.h"
#include "pic24.h"
#include "serial.h"
#include "util.h"

/* Console log */
#define WIDTH (16)

#endif /* !_EASY_LOADER_H */
