/*------------------------------------------------------------------------------
;
;   Easy Loader.
;
;   Compatible with The Cowboy Boot Loader for Enhanced PIC12/PIC16,
;                   The Wellington Boot Loader for PIC18 and
;                   The Oxford Boot Loader for dsPIC/PIC24.
;
;   Copyright (c) 2014 - 2017 Darron M Broad
;   Copyright (c) 2014 Gerhard Bertelsmann
;
;-------------------------------------------------------------------------------

;-------------------------------------------------------------------------------
;   This file is part of Easy Loader.
;
;   Easy Loader is free software: you can redistribute it and/or
;   modify it under the terms of the GNU General Public License as published
;   by the Free Software Foundation.
;
;   Easy Loader is distributed in the hope that it will be
;   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
;   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
;   GNU General Public License for more details.
;
;   You should have received a copy of the GNU General Public License along
;   with Easy Loader. If not, see http://www.gnu.org/licenses/
;-----------------------------------------------------------------------------*/

#include "easy-loader.h"

/******************************************************************************
 *
 * Session
 *
 *****************************************************************************/

extern session_t easy;

/*******************************************************************************
 *
 * Blank row tests
 *
 ******************************************************************************/
uint8_t
pic_isBlank8(uint8_t *buffer, uint32_t buflen)
{
	for (uint32_t i = 0; i < buflen; ++i)
		if (buffer[i] != 0xFF)
			return 0;

	return 1;
}

uint8_t
pic_isBlank14(uint16_t *buffer, uint32_t buflen)
{
	for (uint32_t i = 0; i < buflen; ++i)
		if (buffer[i] != 0x3FFF)
			return 0;

	return 1;
}

uint8_t
pic_isBlank16(uint16_t *buffer, uint32_t buflen)
{
	for (uint32_t i = 0; i < buflen; ++i)
		if (buffer[i] != 0xFFFF)
			return 0;

	return 1;
}

uint8_t
pic_isBlank24(uint32_t *buffer, uint32_t buflen)
{
	for (uint32_t i = 0; i < buflen; ++i)
		if ((buffer[i] & 0xFFFFFF) != 0xFFFFFF)
			return 0;

	return 1;
}

/*******************************************************************************
 *
 * Dump content
 *
 ******************************************************************************/
int
pic_dumpFlash(void)
{
	if (easy.arch == 14)
		return pic14_dumpFlash();
	if (easy.arch == 16)
		return pic16_dumpFlash();
	if (easy.arch == 24)
		return pic24_dumpFlash();

	return -1;
}

int
pic_dumpEEPROM(void)
{
	if (easy.eesize == 0) {
		printf("[NONE]\n");
		return 0;
	}

	if (easy.arch == 14)
		return pic14_dumpEEPROM();
	if (easy.arch == 16)
		return pic16_dumpEEPROM();
	if (easy.arch == 24)
		return pic24_dumpEEPROM();

	return -1;
}

/*******************************************************************************
 *
 * Program content
 *
 ******************************************************************************/
int
pic_program(char *filename)
{
	if (easy.arch == 14)
		return pic14_program(filename);
	if (easy.arch == 16)
		return pic16_program(filename);
	if (easy.arch == 24)
		return pic24_program(filename);

	return -1;
}

/*******************************************************************************
 *
 * Zap zero page
 *
 ******************************************************************************/
int
pic_zap(uint32_t raddress)
{
	if (easy.arch == 14)
		return pic14_erase_row(raddress);
	if (easy.arch == 16)
		return pic16_erase_row(raddress);
	if (easy.arch == 24)
		return pic24_erase_row(raddress);

	return -1;
}
