/*------------------------------------------------------------------------------
;
;   Easy Loader.
;
;   Compatible with The Cowboy Boot Loader for Enhanced PIC12/PIC16,
;                   The Wellington Boot Loader for PIC18 and
;                   The Oxford Boot Loader for dsPIC/PIC24.
;
;   Copyright (c) 2014 - 2017 Darron M Broad
;   Copyright (c) 2014 Gerhard Bertelsmann
;
;-------------------------------------------------------------------------------

;-------------------------------------------------------------------------------
;   This file is part of Easy Loader.
;
;   Easy Loader is free software: you can redistribute it and/or
;   modify it under the terms of the GNU General Public License as published
;   by the Free Software Foundation.
;
;   Easy Loader is distributed in the hope that it will be
;   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
;   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
;   GNU General Public License for more details.
;
;   You should have received a copy of the GNU General Public License along
;   with Easy Loader. If not, see http://www.gnu.org/licenses/
;-----------------------------------------------------------------------------*/

#include "easy-loader.h"

/*******************************************************************************
 *
 * Malloc with panic on error
 *
 ******************************************************************************/
void *
xmalloc(size_t n, int c)
{
	void *s;

	if (!n)
		return NULL;
	s = malloc(n);
	if (s == NULL)
		exit(EX_OSERR);
	return memset(s, c, n);
}

/*******************************************************************************
 *
 * Free with sanity check
 *
 ******************************************************************************/
void *
xfree(void *s)
{
	if (s)
		free(s);
	return NULL;
}

/*******************************************************************************
 *
 * Run command
 *
 ******************************************************************************/
int
run(const char *command)
{
	FILE *p;
	char s[BUFLEN];

	p = popen(command, "r");
	if (p == NULL)
		return -1;

	while (fgets(s, BUFLEN, p) != NULL) {
		;
	}

	pclose(p);

	return 0;
}
